@@ -4,7 +4,7 @@ from dataclasses import dataclass
 
 @dataclass
 class ProofStats:
-    """Stats on how complex a proof was to complete"""
+    """Stats on how complex a proof was to compute"""
 
     attempted_unifications: int = 0
     successful_unifications: int = 0
@@ -15,3 +15,5 @@ class ProofStats:
     max_resolvent_width_seen: int = 0
     max_depth_seen: int = 0
     discarded_proofs: int = 0
+    resolvent_checks: int = 0
+    resolvent_check_hits: int = 0
