@@ -16,6 +16,8 @@ def subsitutions_to_str(substitutions: SubstitutionsMap) -> str:
 
 @dataclass
 class ProofStep:
+    """A single step in a proof of a goal"""
+
     source: CNFDisjunction
     target: CNFDisjunction
     source_unification_literal: CNFLiteral
@@ -26,6 +28,7 @@ class ProofStep:
     similarity: float
     # this refers to the overall similarity of this step and all of its parents
     running_similarity: float
+    depth: int
     parent: Optional[ProofStep] = None
 
     def __str__(self) -> str:
