@@ -14,9 +14,17 @@ if TYPE_CHECKING:
 
 @dataclass(frozen=True)
 class Predicate:
+    """
+    A predicate symbol in a logical formula.
+    Can contain an embedding for use in vector similarity calculations.
+    """
+
     symbol: str
     embedding: Optional[Any] = None
 
+    def __hash__(self) -> int:
+        return hash(self.symbol) + id(self.embedding)
+
     # shorthand for creating an Atom out of this predicate and terms
     def __call__(self, *terms: Constant | Variable | BoundFunction) -> Atom:
         # need to import inside of here to avoid circular references
